@@ -95,6 +95,7 @@ BayonneBinder("ivrscript1")
 	ScriptInterp::addConditional("extension", &testExternal);
 	ScriptInterp::addConditional("external", &testExternal);
 	ScriptInterp::addConditional("reachable", &testReachable);
+	ScriptInterp::addConditional("destination", &testDestination);
 
 	Bayonne::use_prefix = true;
 	Bayonne::use_macros = true;
@@ -487,6 +488,18 @@ bool Binder::testAvailable(ScriptInterp *inter, const char *v)
 	return d->isAvailable(v);
 }  
 
+bool Binder::testDestination(ScriptInterp *interp, const char *v)
+{
+	char name[80];
+	ScriptImage *img = interp->getImage();
+	snprintf(name, sizeof(name), "dialed::%s", v);
+	
+	if(img->getScript(name))
+		return true;
+
+	return false;
+}
+
 bool Binder::testReachable(ScriptInterp *inter, const char *v)
 {
 	BayonneDriver *d = NULL;
