@@ -86,6 +86,68 @@ class __EXPORT BayonneService;
 class __EXPORT BayonneTranslator;
 class __EXPORT BayonneRPC;
 
+/**
+ * Streaming buffer for audio, to be used in bgm audio sources.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short audio buffering
+ */
+class __EXPORT StreamingBuffer : public Audio
+{
+private:
+	static StreamingBuffer *first;
+	StreamingBuffer *next;
+	const char *id;
+	Rate rate;
+
+protected:
+	unsigned long position, count;
+	Linear data;
+
+	void cleanup();
+
+	StreamingBuffer(const char *id, timeout_t size = 600, Rate rate = rate8khz);
+	virtual ~StreamingBuffer();
+
+    virtual Linear putBuffer(timeout_t duration);
+	virtual void clearBuffer(timeout_t duration);
+
+public:
+	/**
+	 * Find a streaming feed by identifier.
+	 *
+	 * @return pointer to feed or NULL.
+	 * @param identifer to search for.
+	 * @param sample rate to use.
+	 */
+	static StreamingBuffer *get(const char *id, Rate rate);
+
+	/**
+	 * Check if streaming source is active.	
+	 *
+	 * @return true if active.
+	 */
+	virtual bool isActive(void);
+
+	/**
+	 * Get position marker we use in audio consumer.
+	 *
+	 * @param framing size we will use.
+	 * @return consumer position.
+	 */
+	virtual unsigned long getPosition(timeout_t framing);
+
+	/**
+	 * Used by consumer to get a linear buffer of audio data.
+	 *
+	 * @return data buffer of samples.
+	 * @param consumer position.
+	 * @param timeout of frame for updating position.
+	 */
+	virtual Linear getBuffer(unsigned long *mark, timeout_t duration);
+};
+	
+
 /**
  * Bayonnne specific static keydata class.  This is used for configuration
  * keys which cannot be reloaded at runtime.
@@ -162,13 +224,12 @@ protected:
 	timeout_t updatedMsecTimer(const char *id);
 	bool updatedBoolean(const char *id);
 
-	// used for special purposes for clarity, future api...
+public:
 	inline const char *getInitial(const char *id)
 		{return StaticKeydata::getString(id);};
 	inline void setInitial(const char *id, const char *val)
 		{StaticKeydata::setValue(id, val);};
 
-public:
 	ReconfigKeydata(const char *keypath, Keydata::Define *def = NULL);
 
 	const char *getString(const char *key, char *buf, size_t size);
