@@ -738,7 +738,7 @@ void Driver::startDriver(void)
 	char *p;
 	const char *cp;
 	unsigned max_count = ts_limit;
-	cp = server->getLast("slots.sip");
+	cp = getLast("timeslots");
 	int rtn;
 
 	exiting = false;
