@@ -46,6 +46,8 @@ using namespace std;
 Session::Session(TCPSocket &server) :
 TCPSession(server)
 {
+	if(so > -1 && (unsigned)so < (sizeof(fd_set) * 8))
+		++Service::sequence[so];
 	monmap = new char[ts_used];
 	memset(monmap, 0, ts_used);
 }
@@ -441,6 +443,7 @@ void Session::run(void)
 	BayonneSession *session;
 	bool login = false;
 	int retries = 0;
+	char exitbuf[16];
 	char buffer[256];
 	char *argv[128];
 	char *tok;
@@ -629,6 +632,12 @@ void Session::run(void)
 					*tcp() << "*** session unable to start call" << endl;
 				else
 				{
+					if((unsigned)so < (sizeof(fd_set) * 8))
+					{
+						snprintf(exitbuf, sizeof(exitbuf), "tcpmon:%d,%d",
+							so, Service::sequence[so]);
+						session->setConst("exit_manager", exitbuf);
+					}
 					*tcp() << "starting call " << session->getExternal("session.id") << endl;
 					session->leave();
 				}
