@@ -36,7 +36,7 @@ using namespace std;
 #define	MAX_XML_REQUEST		2048
 #define	MAX_XML_REPLY		16384
 
-class Service : public BayonneService, public BayonneZeroconf, public Keydata
+class Service : public BayonneService, public BayonneZeroconf, public StaticKeydata
 {
 private:
 	void run(void);
@@ -45,7 +45,7 @@ private:
 public:
 	static bool active;
 	static Service webservice;
-	static Keydata admin, rpc;
+	static DynamicKeydata admin, rpc;
 	Service();
 };
 
