@@ -26,6 +26,18 @@ typedef	Bayonne::rpcint_t rpcint_t;
 typedef	rpcint_t rpcbool_t;
 typedef	Bayonne::regauth_t registry_t;
 
+static void driver_version(BayonneRPC *rpc)
+{
+    if(rpc->getCount())
+    {
+        rpc->sendFault(3, "Invalid Parameters");
+        return;
+    }
+	rpc->buildResponse("(ii)", 
+		"current", (rpcint_t)1,
+		"prior", (rpcint_t)0);
+}
+
 static void driver_getInfo(BayonneRPC *rpc)
 {
 	BayonneDriver *driver = NULL;
@@ -339,6 +351,8 @@ static void driver_callstats(BayonneRPC *rpc)
 }
 
 static Bayonne::RPCDefine dispatch[] = {
+	{"version", driver_version,
+		"API version of driver rpc", "int"},
 	{"suspend", driver_suspend,
 		"Suspend driver", "boolean, string"},
 	{"resume", driver_resume,
