@@ -35,6 +35,17 @@ const char *Checks::chkSay(Line *line, ScriptImage *img)
 	return NULL;
 }		
 
+const char *Checks::chkExit(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "exit has no members";
+
+	if(line->argc > 1)
+		return "exit only has one reason argument";
+
+	return NULL;
+}
+
 const char *Checks::chkPaths(Line *line, ScriptImage *img)
 {	
 	unsigned idx = 0;
