@@ -128,6 +128,8 @@ ScriptRuntime()
 			(Check)&Checks::chkLibexec},
 		{"exec", false, (Method)&Methods::scrLibexec,
 			(Check)&Checks::chkLibexec},
+		{"exit", false, (Method)&Methods::scrExit,
+			(Check)&Checks::chkExit},
 		{"cleardigits", false, (Method)&Methods::scrCleardigits,
 			(Check)&Checks::chkCleardigits},
 		{"replay", false, (Method)&Methods::scrReplay,
