@@ -118,6 +118,23 @@ static void plugins(void)
 	}	
 }	
 
+static void setTimeslots(BayonneDriver *driver)
+{
+	const char *type = driver->getLast("type");
+	if(!type || stricmp(type, "proto"))
+		return;
+	
+	type = driver->getLast("proto");
+	if(!type)
+		return;
+
+	type = keyengine.getLast(type);
+	if(!type || atoi(type) == 0)
+		return;
+
+	driver->setInitial("timeslots", type);
+}
+	
 static void loading(void)
 {
 	char buffer[256];
@@ -133,6 +150,7 @@ static void loading(void)
 	size_t bs = 0;
 	int pri = 0;
 #endif
+	unsigned driver_count = 0;
 
 	if(!Process::getEnv("SERVER_SYSEXEC"))
 		Process::setEnv("SERVER_SYSEXEC", keypaths.getLast("scripts"), true);
@@ -244,14 +262,17 @@ static void loading(void)
 	if(cp && *cp)
 		driver = BayonneDriver::loadDriver(cp);
 
-	if(!driver)
+	if(driver)
 	{
-		slog.critical("no driver loaded; enable in server.conf...");
-		stop(-1);
+		setTimeslots(driver);
+		++driver_count;
 	}
 
 	proto = NULL;
 	cp = keyengine.getLast("protocol");
+	if(!cp)
+		cp = keyengine.getLast("protocols");
+
 #ifndef	WIN32
 	if(cp && !stricmp(cp, "default"))
 	{
@@ -262,9 +283,29 @@ static void loading(void)
 #endif
 	if(cp && !stricmp(cp, "none"))
 		cp = NULL;
-	if(cp)
-		proto = BayonneDriver::loadDriver(cp);
 
+	if(cp)
+	{
+		setString(buffer, sizeof(buffer), cp);
+		sp = strtok_r(buffer, ",;:\t \r\n", &tok);
+		while(sp)
+		{
+			proto = BayonneDriver::loadDriver(cp);
+			if(proto)
+			{
+				++driver_count;
+				setTimeslots(proto);
+			}
+			sp = strtok_r(NULL, ",;:\t \r\n", &tok);
+		}
+	}
+
+	if(!driver_count)
+	{
+		slog.critical("no drivers loaded; exiting...");
+		exit(-1);
+	}
+		
 	sp = (char *)keyserver.getLast("monitoring");
 	if(sp && !strnicmp(sp, "no", 2))
 		sp = NULL;
